# Info (I)

Informational messages that highlight potential issues but are not validation failures.

| Code | Description                                    |
|------|------------------------------------------------|
| I001 | Registered skill path no longer exists on disk |
